Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
ADPLAY(1)			  User Commands 		       ADPLAY(1)

NAME
     adplay - AdPlay/UNIX console-based OPL2 audio player

SYNOPSIS
     adplay [OPTION]... FILE...

DESCRIPTION
     AdPlay/UNIX  is AdPlug's UNIX console-based frontend. It tries to play back
     all given FILEs, using one of many available output mechanisms.

     AdPlay/UNIX plays endlessly, if only  one	file  is  given.  With	multiple
     files,  it plays them in a sequence and exits after the last file. The same
     can also be accomplished with only one file, by using the -o  option.  When
     using the disk writer, -o is implied.

EXIT STATUS
     adplay returns 0 on successful operation. 1 is returned otherwise.

OUTPUT MECHANISMS
     AdPlay/UNIX can play back using many different output mechanisms, which can
     be  selected  with the -O argument. The availability of a method depends on
     compile-time settings. Available methods are printed  out	after  the  help
     text, displayed with --help.

     Next  is  a brief description of all output mechanisms, following their ab-
     breviations:

   oss -- Open Sound System (OSS) driver
     This output method is available on most Linux and other UNIX systems.

   null -- Total silence
     Discards anything sent to it. It can be useful for testing purposes.

   disk -- Disk writer
     Writes its output to a file in Microsoft RIFF WAVE format.

   esound -- EsounD output
     Creates a socket connection to an EsounD server and streams  the  audio  to
     it.

   qsa -- QNX Sound Architecture (QSA) driver
     Uses the QNX system's standard output method.

   sdl -- Simple Directmedia Layer (SDL) driver
     Uses  the	SDL library for sound output. The library has a broader platform
     support than any of the other output methods. Thus, it could be  useful  on
     some exotic systems.

   alsa -- Advanced Linux Sound Architecture (ALSA) driver
     Uses the standard output method on newer Linux systems.

   ao -- libao driver
     Libao  is	a cross-platform audio library with very broad platform support.
     Might be useful on systems, where SDL is not available, and generally to do
     tricky things.

OPTIONS
     The order of the option commandline parameters is not important, except for
     the -d option, which always has to be specified after an -O option.

   Output selection:
     -O, --output=OUTPUT
	    Specify output mechanism. Available mechanisms depend on compilation
	    settings and are printed on --help output. A reasonable  default  is
	    automatically  selected,  based  on  the  availability of the output
	    mechanisms.

   OSS driver (oss) specific:
     -d --device=FILE
	    Set sound output device file to FILE. This is /dev/dsp by default.

   Disk writer (disk) specific:
     -d --device=FILE
	    Write sound data to FILE. The data is written in Microsoft RIFF WAVE
	    format (little-endian). You can specify a single  '-'  to  write  to
	    stdout  instead.  This  option  has no default and must be specified
	    when the disk writer is to be used!

   EsounD output (esound) specific:
     -d --device=URL
	    Connect  to  "hostname:port"  combination  in  URL.  Example:   "my-
	    host.sound.net:1234". The default is "localhost:16001".

   ALSA driver (alsa) specific:
     -d --device=DEVICE
	    Set sound output device to DEVICE. This is plughw:0,0 by default.

   Playback quality:
     -8, --8bit
	    Use only 8-bit samples for playback.

     --16bit
	    Use only 16-bit samples for playback (default).

     -f, --freq=FREQ
	    Set playback frequency to FREQ, in Hz. This is 44100Hz by default.

     --stereo
	    Use  only stereo samples for playback. The sound stream is just dou-
	    bled, no further audio processing is done.	This  option  is  pretty
	    useless  unless  you  have very obscure audio hardware that only ac-
	    cepts stereo streams. AdPlug only generates mono streams because the
	    OPL2 only generates mono sound.

     --mono
	    Use only mono samples for playback (default if AdPlug <= 2.1.)

     --surround
	    Use only stereo samples for playback, but  generate  them  from  two
	    mono  OPL2 chips.  One OPL2 chip is very slightly transposed to pro-
	    duce a pleasant harmonic/surround sound effect (default if AdPlug >=
	    2.2.)

     -b --buffer=SIZE
	    Set sound buffer size to SIZE samples. If you notice sound	skipping
	    with  the default setting, try a greater buffer size. Note that this
	    is measured in samples, not bytes! This is 2048 samples by	default.
	    Only  the  OSS,  SDL, ALSA and libao output drivers support this op-
	    tion.

   Informative output:
     -i --instruments
	    Display instrument names (if available).

     -r --realtime
	    Display realtime playback information, while playing. This will dis-
	    play a one-line status bar, containing essential  playback	informa-
	    tion.

     -m --message
	    Display the song message (if available).

   Playback:
     -s --subsong=N
	    Play  subsong  number N, instead of the default subsong of the file.
	    Only useful for file formats that support multiple subsongs.

     -o --once
	    Don't loop endlessly. This will exit adplay after  the  song  ended.
	    This is the default when multiple FILEs are given.

     -l --loop=N
	    Loop  N  times then stop. Due to technical limitations of the adplug
	    library, a "loop" is considered to be the time between the start  of
	    playback  and  when  looping first occurs. Accordingly, playback may
	    actually halt at an unexpected point, especially when combined  with
	    -s. This implies -o.

   Miscellaneous:
     -D, --database=FILE
	    Additionally  use  database  file FILE. This option may be specified
	    multiple times. Each database file is additionally merged  with  the
	    others, creating one large database on the fly.

     -q, --quiet
	    Be more quiet.

     -v, --verbose
	    Be more verbose.

     -h, --help
	    Show summary of options.

     -V, --version
	    Show version of program.

AUTHOR
     Simon Peter <dn.tlp@gmx.net>

AdPlay/UNIX 1.9 		December 21, 2025		       ADPLAY(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=adplay&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help